@@ -6,21 +6,26 @@
                                    rmHzErrors = TRUE,
                                    nullFragsAreZero = TRUE,
                                    fill = FALSE,
-                                   stringsAsFactors = default.stringsAsFactors(),
+                                   stringsAsFactors = NULL,
                                    dsn = NULL) {
 
-
+  
+  if (!missing(stringsAsFactors) && is.logical(stringsAsFactors)) {
+    .Deprecated(msg = sprintf("stringsAsFactors argument is deprecated.\nSetting package option with `NASISDomainsAsFactor(%s)`", stringsAsFactors))
+    NASISDomainsAsFactor(stringsAsFactors)
+  }
+  
   # ensure that any old hz errors are cleared
   if(exists('component.hz.problems', envir=soilDB.env))
     assign('component.hz.problems', value=character(0), envir=soilDB.env)
 
   # load data in pieces
-  f.comp       <- get_component_data_from_NASIS_db(SS = SS, stringsAsFactors = stringsAsFactors, dsn = dsn, nullFragsAreZero = nullFragsAreZero)
+  f.comp       <- get_component_data_from_NASIS_db(SS = SS, dsn = dsn, nullFragsAreZero = nullFragsAreZero)
   f.chorizon   <- get_component_horizon_data_from_NASIS_db(SS = SS, fill = fill, dsn = dsn, nullFragsAreZero = nullFragsAreZero)
-  f.copm       <- get_component_copm_data_from_NASIS_db(SS = SS, stringsAsFactors = stringsAsFactors, dsn = dsn)
+  f.copm       <- get_component_copm_data_from_NASIS_db(SS = SS, dsn = dsn)
   f.cogeomorph <- get_component_cogeomorph_data_from_NASIS_db2(SS = SS, dsn = dsn)
   f.otherveg   <- get_component_otherveg_data_from_NASIS_db(SS = SS, dsn = dsn)
-  f.ecosite    <- get_component_esd_data_from_NASIS_db(SS = SS, stringsAsFactors = stringsAsFactors, dsn = dsn)
+  f.ecosite    <- get_component_esd_data_from_NASIS_db(SS = SS, dsn = dsn)
   f.diaghz     <- get_component_diaghz_from_NASIS_db(SS = SS, dsn = dsn)
   f.restrict   <- get_component_restrictions_from_NASIS_db(SS = SS, dsn = dsn)
 
