@@ -1,7 +1,4 @@
-get_RMF_from_NASIS_db <- function(SS=TRUE) {
-  # must have RODBC installed
-  if(!requireNamespace('RODBC'))
-    stop('please install the `RODBC` package', call.=FALSE)
+get_RMF_from_NASIS_db <- function(SS=TRUE, dsn = NULL) {
 
   # RMF
   # unique-ness enforced via peiid (pedon-level) and phiid (horizon-level)
@@ -19,36 +16,34 @@ get_RMF_from_NASIS_db <- function(SS=TRUE) {
   FROM phredoxfcolor_View_1
   ORDER BY phrdxfiidref, colormoistst;"
 
-  channel <- .openNASISchannel()
-  if (channel == -1)
+  channel <- dbConnectNASIS(dsn)
+
+  if (inherits(channel, 'try-error'))
     return(data.frame())
 
   # toggle selected set vs. local DB
-  if(SS == FALSE) {
+  if (SS == FALSE) {
     q <- gsub(pattern = '_View_1', replacement = '', x = q, fixed = TRUE)
     q.c <- gsub(pattern = '_View_1', replacement = '', x = q.c, fixed = TRUE)
   }
 
   # exec queries
-  d <- RODBC::sqlQuery(channel, q, stringsAsFactors=FALSE)
-  d.c <- RODBC::sqlQuery(channel, q.c, stringsAsFactors=FALSE)
-
-  # close connection
-  RODBC::odbcClose(channel)
+  d <- dbQueryNASIS(channel, q, close = FALSE)
+  d.c <- dbQueryNASIS(channel, q.c)
 
   # uncode domained columns
-  d <- uncode(d)
-  d.c <- uncode(d.c)
+  d <- uncode(d, dsn = dsn)
+  d.c <- uncode(d.c, dsn = dsn)
 
   # convert back to characters / numeric
   d.c$colormoistst <- as.character(d.c$colormoistst)
   d.c$colorhue <- as.character(d.c$colorhue)
-  # careful!
+
   # uncode creates factors, so we have to convert to character first
   d.c$colorvalue <- as.numeric(as.character(d.c$colorvalue))
   d.c$colorchroma <- as.numeric(as.character(d.c$colorchroma))
 
 
   # done
-  return(list(RMF=d, RMF_colors=d.c))
+  return(list(RMF = d, RMF_colors = d.c))
 }
