@@ -1,4 +1,9 @@
-get_cosoilmoist_from_NASISWebReport <- function(projectname, impute = TRUE, stringsAsFactors = default.stringsAsFactors()) {
+get_cosoilmoist_from_NASISWebReport <- function(projectname, impute = TRUE, stringsAsFactors = NULL) {
+  
+  if (!missing(stringsAsFactors) && is.logical(stringsAsFactors)) {
+    .Deprecated(msg = sprintf("stringsAsFactors argument is deprecated.\nSetting package option with `NASISDomainsAsFactor(%s)`", stringsAsFactors))
+    NASISDomainsAsFactor(stringsAsFactors)
+  }
   
   # check for required packages
   url <- "https://nasis.sc.egov.usda.gov/NasisReportsWebSite/limsreport.aspx?report_name=get_cosoimoist_from_NASISWebReport"
@@ -10,12 +15,12 @@ get_cosoilmoist_from_NASISWebReport <- function(projectname, impute = TRUE, stri
   d.cosoilmoist <- do.call("rbind", d.cosoilmoist)
 
   # set factor levels according to metadata domains
-  d.cosoilmoist <- uncode(d.cosoilmoist, db = "LIMS", stringsAsFactors = TRUE)
+  d.cosoilmoist <- uncode(d.cosoilmoist, db = "LIMS")
   
   # prep dataset: rename columns, impute empty values, stringsAsFactors
-  d.cosoilmoist <- .cosoilmoist_prep(d.cosoilmoist, impute = impute, stringsAsFactors = stringsAsFactors)
+  d.cosoilmoist <- .cosoilmoist_prep(d.cosoilmoist, impute = impute)
   
-  # return data.fram
+  # return data.frame
   return(d.cosoilmoist)
   }
 
