@@ -24,12 +24,6 @@
 #' Reports, the metadata is pulled from a static snapshot in the soilDB
 #' package.
 #'
-#' Beware the default is to return the values as factors rather than strings.
-#' While strings are generally preferable, factors make plotting more
-#' convenient. Generally the factor level ordering returned by uncode() follows
-#' the naturally ordering of categories that would be expected (e.g. sand,
-#' silt, clay).
-#'
 #' @aliases metadata uncode code
 #'
 #' @param df data.frame
@@ -44,8 +38,7 @@
 #' classifying factors. This is useful when a class has large number of unused
 #' classes, which can waste space in tables and figures.
 #'
-#' @param stringsAsFactors logical: should character vectors be converted to
-#' factors?
+#' @param stringsAsFactors deprecated
 #'
 #' @param dsn Optional: path to local SQLite database containing NASIS
 #' table structure; default: `NULL`
@@ -74,36 +67,19 @@ uncode <- function(df,
                    invert = FALSE,
                    db = "NASIS",
                    droplevels = FALSE,
-                   stringsAsFactors = default.stringsAsFactors(),
+                   stringsAsFactors = NULL,
                    dsn = NULL) {
-
-  get_metadata <- function() {
-
-    q <- "SELECT mdd.DomainID, DomainName, ChoiceSequence, ChoiceValue, ChoiceName,
-                 ChoiceLabel, ColumnPhysicalName, ColumnLogicalName, ChoiceObsolete, ChoiceDescription
-          FROM MetadataDomainDetail mdd
-            INNER JOIN MetadataDomainMaster mdm ON mdm.DomainID = mdd.DomainID
-            INNER JOIN (SELECT MIN(DomainID) DomainID, MIN(ColumnPhysicalName) ColumnPhysicalName, MIN(ColumnLogicalName) ColumnLogicalName
-                        FROM MetadataTableColumn GROUP BY DomainID, ColumnPhysicalName) mtc ON mtc.DomainID = mdd.DomainID
-          ORDER BY mdd.DomainID, ColumnPhysicalName, ChoiceValue;"
-
-    channel <- dbConnectNASIS(dsn)
-
-    if (inherits(channel, 'try-error'))
-      return(data.frame())
-
-    # exec query
-    d <- dbQueryNASIS(channel, q)
-
-    # done
-    return(d)
+  
+  if (!missing(stringsAsFactors) && is.logical(stringsAsFactors)) {
+    .Deprecated(msg = sprintf("stringsAsFactors argument is deprecated.\nSetting package option with `NASISDomainsAsFactor(%s)`", stringsAsFactors))
+    NASISDomainsAsFactor(stringsAsFactors)
   }
-
+  
   # load current metadata table
   if (db == "NASIS") {
-    metadata <- get_metadata()
+    metadata <- .get_NASIS_metadata(dsn = dsn)
   } else {
-      load(system.file("data/metadata.rda", package = "soilDB")[1])
+    load(system.file("data/metadata.rda", package = "soilDB")[1])
   }
 
   # unique set of possible columns that will need replacement
@@ -119,52 +95,95 @@ uncode <- function(df,
   columnsToWorkOn.idx <- which(nm %in% possibleReplacements)
 
   # iterate over columns with codes
-  for (i in columnsToWorkOn.idx){
-
+  for (i in columnsToWorkOn.idx) {
     # get the current metadata
-    sub <- metadata[metadata[[metadata_col]] %in% nm[i], ]
-
+    sub <- metadata[metadata[[metadata_col]] %in% nm[i],]
+    
     # NASIS or LIMS
     if (db %in% c("NASIS", "LIMS")) {
-      if (invert == FALSE){
+      if (invert == FALSE) {
         # replace codes with values
         df[, i] <- factor(df[, i], levels = sub[[value_col]], labels = sub[[name_col]])
       } else {
         # replace values with codes
-        df[, i] <- factor(df[, i], levels = sub[[name_col]], labels = sub[[value_col]])}
+        df[, i] <- factor(df[, i], levels = sub[[name_col]], labels = sub[[value_col]])
+      }
     }
 
     # SDA
     if (db == "SDA") {
-      if (invert == FALSE){
+      if (invert == FALSE) {
         # replace codes with values
         df[, i] <- factor(df[, i], levels = sub[[label_col]])
       } else {
         # replace values with codes
         df[, i] <- factor(df[, i], levels = sub[[label_col]], labels = sub[[value_col]])
-        }
       }
     }
+  }
 
   # drop unused levels
   if (droplevels == TRUE) {
-    idx <- which(! nm %in% possibleReplacements)
+    idx <- which(!nm %in% possibleReplacements)
     df <- droplevels(df, except = idx)
-    }
+  }
 
-  # convert factors to strings
-  if (stringsAsFactors == FALSE) {
+  # convert factors to strings, check soilDB option first
+  if ((length(stringsAsFactors) > 0 && !stringsAsFactors) ||
+      !getOption("soilDB.NASIS.DomainsAsFactor", default = FALSE)){
     idx <- unlist(lapply(df, is.factor))
     df[idx] <- lapply(df[idx], as.character)
   }
-
+  
   return(df)
 }
 
+.get_NASIS_metadata <- function(dsn = NULL) {
+  
+  q <- "SELECT mdd.DomainID, DomainName, DomainRanked, DisplayLabel, 
+               ChoiceSequence, ChoiceValue, ChoiceName, ChoiceLabel, ChoiceObsolete, ChoiceDescription, 
+               ColumnPhysicalName, ColumnLogicalName
+          FROM MetadataDomainDetail mdd
+            INNER JOIN MetadataDomainMaster mdm ON mdm.DomainID = mdd.DomainID
+            INNER JOIN (SELECT MIN(DomainID) DomainID, MIN(ColumnPhysicalName) ColumnPhysicalName, MIN(ColumnLogicalName) ColumnLogicalName
+                        FROM MetadataTableColumn GROUP BY DomainID, ColumnPhysicalName) mtc ON mtc.DomainID = mdd.DomainID
+          ORDER BY mdd.DomainID, ColumnPhysicalName, ChoiceValue;"
+  
+  channel <- dbConnectNASIS(dsn)
+  
+  if (inherits(channel, 'try-error'))
+    return(data.frame())
+  
+  # exec query
+  d <- dbQueryNASIS(channel, q)
+  
+  # done
+  return(d)
+}
+
 # convenient, inverted version of uncode()
 code <- function(df, ...) {
-  res <- uncode(df, invert=TRUE, ...)
+  res <- uncode(df, invert = TRUE, ...)
   return(res)
 }
 
+#' Get/Set Options for Encoding NASIS Domains as Factors
+#' 
+#' Set package option `soilDB.NASIS.DomainsAsFactor` for returning coded NASIS domains as factors. 
+#'
+#' @param x logical; default `FALSE`
+#'
+#' @return logical, result of `getOption("soilDB.NASIS.DomainsAsFactor")`
+#' @export
+#'
+#' @examples
+#' \dontrun{
+#' NASISDomansAsFactor(TRUE)
+#' }
+NASISDomainsAsFactor <- function(x = NULL) {
+  if (!is.null(x)) {
+     options(soilDB.NASIS.DomainsAsFactor = (x || getOption("stringsAsFactors", default = FALSE)))
+  }
+  invisible(getOption("soilDB.NASIS.DomainsAsFactor", default = FALSE))
+}
 
